@@ -1,5 +1,4 @@
-from botty.callbacks import ReplyCallback
-from botty.keyboards import InlineKeyboard
+from botty.callbacks import ReplyCallback, ReplyCallbackKeyboard, ReplyCallbackText
 from botty.triggers import StartGroupTrigger
 
 from .command import CommandHandler
@@ -13,8 +12,8 @@ class StartHandler(CommandHandler):
 class StartReplyHandler(StartHandler):
     def __init__(
         self,
-        text: str | None = None,
-        keyboard: InlineKeyboard | None = None,
+        text: ReplyCallbackText,
+        keyboard: ReplyCallbackKeyboard = None,
     ) -> None:
         callback = ReplyCallback(text, keyboard)
         super().__init__(callback)
@@ -28,8 +27,8 @@ class StartGroupHandler(StartHandler):
 class StartGroupReplyHandler(StartGroupHandler):
     def __init__(
         self,
-        text: str | None = None,
-        keyboard: InlineKeyboard | None = None,
+        text: ReplyCallbackText,
+        keyboard: ReplyCallbackKeyboard = None,
     ) -> None:
         callback = ReplyCallback(text, keyboard)
         super().__init__(callback)
