@@ -1,5 +1,4 @@
-from botty.callbacks import ReplyCallback
-from botty.keyboards import InlineKeyboard
+from botty.callbacks import ReplyCallback, ReplyCallbackKeyboard, ReplyCallbackText
 from botty.triggers import TextTrigger
 
 from .update import UpdateHandler
@@ -13,8 +12,8 @@ class TextHandler(UpdateHandler):
 class TextReplyHandler(TextHandler):
     def __init__(
         self,
-        text: str | None = None,
-        keyboard: InlineKeyboard | None = None,
+        text: ReplyCallbackText,
+        keyboard: ReplyCallbackKeyboard = None,
     ) -> None:
         callback = ReplyCallback(text, keyboard)
         super().__init__(callback)
