@@ -2,7 +2,7 @@ from copy import deepcopy
 
 import telegram
 from botty_core import Callback, Handler
-from botty_core.types import Context, PTBHandler
+from botty_core.types import PTBContext, PTBHandler
 
 from botty.triggers import UpdateTrigger
 
@@ -18,8 +18,8 @@ class UpdateHandler(Handler):
     def build(self) -> PTBHandler:
         return self._trigger.make_handler(self.handle)
 
-    async def handle(self, update: telegram.Update, context: Context) -> None:
+    async def handle(self, update: telegram.Update, context: PTBContext) -> None:
         callback = deepcopy(self._callback)
-        callback.set_update(update, context)
+        callback.set_context(update, context)
         await callback.prepare()
         await callback.run()
