@@ -3,19 +3,20 @@ from typing import TypeVar
 
 import telegram
 
-from botty_core.types import Bot, Context, Update
+from .context import Context
+from .types import Bot, PTBContext, Update
 
 T = TypeVar("T")
 
 
 class Callback(ABC):
     def __init__(self) -> None:
-        self._update: Update | None = None
-        self._context: Context | None = None
+        self._raw_update: telegram.Update | None = None
+        self._raw_context: PTBContext | None = None
 
-    def set_update(self, update: telegram.Update, context: Context) -> None:
-        self._update = Update(update)
-        self._context = context
+    def set_context(self, update: telegram.Update, context: PTBContext) -> None:
+        self._raw_update = update
+        self._raw_context = context
 
     @abstractmethod
     async def run(self) -> None:
@@ -30,17 +31,24 @@ class Callback(ABC):
         return value
 
     @property
-    def update(self) -> Update:
-        return self.get_validated_field("update", self._update)
+    def context(self) -> Context:
+        return Context(self.raw_context, self.raw_update)
 
     @property
-    def context(self) -> Context:
-        return self.get_validated_field("context", self._context)
+    def raw_update(self) -> telegram.Update:
+        return self.get_validated_field("raw_update", self._raw_update)
+
+    @property
+    def raw_context(self) -> PTBContext:
+        return self.get_validated_field("raw_context", self._raw_context)
+
+    @property
+    def update(self) -> Update:
+        return self.context.update
 
     @property
     def bot(self) -> Bot:
-        raw = self.context.bot
-        return Bot(raw)
+        return self.context.bot
 
 
 class CallbackFieldError(AttributeError):
