@@ -11,8 +11,8 @@ from telegram import (
     ext,
 )
 
-Context = ext.ContextTypes.DEFAULT_TYPE
-PTBHandler = ext.BaseHandler[Update, Context]  # type: ignore[misc]
+PTBContext = ext.ContextTypes.DEFAULT_TYPE
+PTBHandler = ext.BaseHandler[Update, PTBContext]  # type: ignore[misc]
 KeyboardMarkup = ReplyKeyboardMarkup | InlineKeyboardMarkup
 ReplyMarkup = KeyboardMarkup | ReplyKeyboardRemove | ForceReply
-PTBCallback = Callable[[telegram.Update, Context], Coroutine[Any, Any, None]]
+PTBCallback = Callable[[telegram.Update, PTBContext], Coroutine[Any, Any, None]]
