@@ -1,10 +1,9 @@
 from botty import CompositeHandler, app
-from botty.handlers import CommandReplyHandler, QueryReplyHandler, StartReplyHandler
+from botty.handlers import CommandReplyHandler, StartReplyHandler
 
 handler = CompositeHandler(
     StartReplyHandler("Hello"),
     CommandReplyHandler("help", "Help"),
-    QueryReplyHandler(text="?"),
 )
 
 app.run(handler)
